@@ -4,12 +4,12 @@ import sys
 import pandas as pd
 
 from .exporter import Exporter
-from ... import RollPass, Unit
-from ...utils.hookutils import applies_to_unit_types
+from pyroll.core import RollPass, Unit
+from pyroll.utils import for_units
 
 
 @Exporter.hookimpl
-@applies_to_unit_types(Unit)
+@for_units(Unit)
 def columns(unit: Unit):
     return dict(
         type=type(unit).__name__,
@@ -18,15 +18,15 @@ def columns(unit: Unit):
 
 
 @Exporter.hookimpl
-@applies_to_unit_types(RollPass)
+@for_units(RollPass)
 def columns(unit: RollPass):
     return dict(
         roll_force=unit.roll_force,
-        roll_torque=unit.roll_torque,
+        roll_torque=unit.roll.roll_torque,
         filling_ratio=unit.out_profile.filling_ratio,
         strain_rate=unit.strain_rate,
-        contact_area=unit.contact_area,
-        contact_length=unit.contact_length
+        contact_area=unit.roll.contact_area,
+        contact_length=unit.roll.contact_length
     )
 
 
